@@ -64,9 +64,9 @@ typedef enum {
  * be square. Since individual icons can be stretched,
  * each icon is not constrained to this nominal size.
  */
-#define NAUTILUS_ICON_SIZE_SMALLEST	12
+#define NAUTILUS_ICON_SIZE_SMALLEST	16
 #define NAUTILUS_ICON_SIZE_SMALLER	24
-#define NAUTILUS_ICON_SIZE_SMALL	36
+#define NAUTILUS_ICON_SIZE_SMALL	32
 #define NAUTILUS_ICON_SIZE_STANDARD	48
 #define NAUTILUS_ICON_SIZE_LARGE	72
 #define NAUTILUS_ICON_SIZE_LARGER	96
@@ -77,12 +77,6 @@ typedef enum {
 /* Maximum size of an icon that the icon factory will ever produce */
 #define NAUTILUS_ICON_MAXIMUM_SIZE     320
 
-/* Icon size to use for menus. NAUTILUS_ICON_SIZE_SMALLEST
- * is a little too small and NAUTILUS_ICON_SIZE_SMALLER is
- * a little too big.
- */
-#define NAUTILUS_ICON_SIZE_FOR_MENUS	20
-
 /* here's a structure to hold the emblem attach points */
 
 #define MAX_ATTACH_POINTS 12
@@ -105,16 +99,21 @@ GObject *             nautilus_icon_factory_get                          (void);
 
 /* Relationship between zoom levels and icons sizes. */
 guint                 nautilus_get_icon_size_for_zoom_level              (NautilusZoomLevel            zoom_level);
+float                 nautilus_get_relative_icon_size_for_zoom_level     (NautilusZoomLevel            zoom_level);
 
 /* Choose the appropriate icon, but don't render it yet. */
 char *                nautilus_icon_factory_get_icon_for_file            (NautilusFile                *file,
 									  gboolean                     embedd_text);
-gboolean              nautilus_icon_factory_is_icon_ready_for_file       (NautilusFile                *file);
-GList *               nautilus_icon_factory_get_required_file_attributes (void);
+gboolean               nautilus_icon_factory_is_icon_ready_for_file       (NautilusFile                *file);
+NautilusFileAttributes nautilus_icon_factory_get_required_file_attributes (void);
 
 GList *               nautilus_icon_factory_get_emblem_icons_for_file    (NautilusFile                *file,
 									  EelStringList               *exclude);
 char *                nautilus_icon_factory_get_emblem_icon_by_name      (const char                  *emblem_name);
+guint                 nautilus_icon_factory_get_emblem_size_for_icon_size (guint                       size);
+
+guint                 nautilus_icon_factory_get_larger_icon_size         (guint size);
+guint                 nautilus_icon_factory_get_smaller_icon_size        (guint size);
 
 /* Render an icon to a particular size.
  * Ownership of a ref. count in this pixbuf comes with the deal.
@@ -124,33 +123,63 @@ char *                nautilus_icon_factory_get_emblem_icon_by_name      (const
  * If the wants_default boolean is set, return a default icon instead
  * of NULL if we can't find anything
  */
-GdkPixbuf *           nautilus_icon_factory_get_pixbuf_for_icon          (const char                  *icon,
-									  const char                  *modifier,
-									  guint                        nominal_size,
-									  NautilusEmblemAttachPoints  *attach_points,
-									  GdkRectangle                *embedded_text_rect,
-									  gboolean                     wants_default,
-									  char                       **display_name);
+GdkPixbuf *nautilus_icon_factory_get_pixbuf_for_icon            (const char                  *icon,
+								 const char                  *modifier,
+								 guint                        nominal_size,
+								 NautilusEmblemAttachPoints  *attach_points,
+								 GdkRectangle                *embedded_text_rect,
+								 gboolean                     force_size,
+								 gboolean                     wants_default,
+								 char                       **display_name);
+GdkPixbuf *nautilus_icon_factory_get_pixbuf_for_icon_with_stock_size (const char                  *icon,
+								      const char                  *modifier,
+								      GtkIconSize                  stock_size,
+								      NautilusEmblemAttachPoints  *attach_points,
+								      GdkRectangle                *embedded_text_rect,
+								      gboolean                     wants_default,
+								      char                       **display_name);
+
 									  
 /* Convenience functions for the common case where you want to choose
  * and render the icon into a pixbuf all at once.
  */
-GdkPixbuf *           nautilus_icon_factory_get_pixbuf_for_file          (NautilusFile                *file,
-									  const char                  *modifer,
-									  guint                        size_in_pixels);
+GdkPixbuf *nautilus_icon_factory_get_pixbuf_for_file            (NautilusFile *file,
+								 const char   *modifer,
+								 guint         size_in_pixels,
+								 gboolean      force_size);
+GdkPixbuf *nautilus_icon_factory_get_pixbuf_for_file_with_stock_size (NautilusFile *file,
+								      const char   *modifier,
+								      GtkIconSize   stock_size);
+
+GdkPixbuf * nautilus_icon_factory_get_pixbuf_for_file_with_icon (NautilusFile               *file,
+								 const char                 *icon,
+								 const char                 *modifier,
+								 guint                       size_in_pixels,
+								 NautilusEmblemAttachPoints *attach_points,
+								 GdkRectangle               *embedded_text_rect,
+								 gboolean                    force_size,
+								 gboolean                    wants_default,
+								 char                      **display_name);
+
 
 /* Convenience routine for getting a pixbuf from an icon name
  */
 GdkPixbuf *           nautilus_icon_factory_get_pixbuf_from_name         (const char                  *icon_name,
 									  const char                  *modifer,
 									  guint                        size_in_pixels,
+									  gboolean                     force_size,
 									  char                       **display_name);
+GdkPixbuf *           nautilus_icon_factory_get_pixbuf_from_name_with_stock_size (const char          *icon_name,
+										  const char          *modifer,
+										  GtkIconSize          stock_size,
+										  char               **display_name);
+
+GtkIconTheme *         nautilus_icon_factory_get_icon_theme        (void);
+GnomeThumbnailFactory *nautilus_icon_factory_get_thumbnail_factory (void);
+gboolean               nautilus_icon_factory_remove_from_cache     (const char *icon_name,
+								    const char *modifier,
+								    guint       size);
 
-GnomeIconTheme *       nautilus_icon_factory_get_icon_theme               (void);
-GnomeThumbnailFactory *nautilus_icon_factory_get_thumbnail_factory        (void);
-gboolean               nautilus_icon_factory_remove_from_cache (const char *icon_name,
-								const char *modifier,
-								guint size);
 
 #endif /* NAUTILUS_ICON_FACTORY_H */
 
