@@ -89,7 +89,7 @@ nautilus_window_info_get_type (void)
 	static GType type = 0;
 	
 	if (!type) {
-		static const GTypeInfo info = {
+		const GTypeInfo info = {
 			sizeof (NautilusWindowInfoIface),
 			nautilus_window_info_base_init,
 			NULL,
