@@ -150,6 +150,7 @@ get_slider_button (NautilusPathBar  *path_bar,
         gtk_widget_push_composite_child ();
 
         button = gtk_button_new ();
+	gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
         gtk_container_add (GTK_CONTAINER (button), gtk_arrow_new (arrow_type, GTK_SHADOW_OUT));
         gtk_container_add (GTK_CONTAINER (path_bar), button);
         gtk_widget_show_all (button);
@@ -1064,25 +1065,19 @@ get_button_image (NautilusPathBar *path_bar,
 		      		return path_bar->home_icon;
 			}
 
-			if (!desktop_is_home) {
-				icon_name = get_icon_name_for_file_path (path_bar->home_path);
-				if (strcmp (icon_name, DEFAULT_ICON) == 0) {
-			        	path_bar->home_icon = nautilus_icon_factory_get_pixbuf_from_name (DEFAULT_HOME_ICON,
+			icon_name = get_icon_name_for_file_path (path_bar->home_path);
+			if (strcmp (icon_name, DEFAULT_ICON) == 0) {
+				path_bar->home_icon = nautilus_icon_factory_get_pixbuf_from_name (DEFAULT_HOME_ICON,
 											  NULL, NAUTILUS_PATH_BAR_ICON_SIZE,
 											  TRUE, NULL);
-				} else {
-					path_bar->home_icon = nautilus_icon_factory_get_pixbuf_from_name (icon_name,
-											  NULL, NAUTILUS_PATH_BAR_ICON_SIZE,
-											  TRUE, NULL);
-				}
-
-				g_free (icon_name);
 			} else {
-				path_bar->home_icon = nautilus_icon_factory_get_pixbuf_from_name (DEFAULT_DESKTOP_ICON,
-											     NULL, NAUTILUS_PATH_BAR_ICON_SIZE,
-											     TRUE, NULL);
+				path_bar->home_icon = nautilus_icon_factory_get_pixbuf_from_name (icon_name,
+											  NULL, NAUTILUS_PATH_BAR_ICON_SIZE,
+											  TRUE, NULL);
 			}
-                       	return path_bar->home_icon;
+
+			g_free (icon_name);
+			return path_bar->home_icon;
 
                 case DESKTOP_BUTTON:
                       	if (path_bar->desktop_icon != NULL) {
@@ -1123,7 +1118,7 @@ button_data_free (ButtonData *button_data)
 static const char *
 get_dir_name (ButtonData *button_data)
 {
-        if (button_data->type == DESKTOP_BUTTON || (button_data->type == HOME_BUTTON && desktop_is_home)) {
+	if (button_data->type == DESKTOP_BUTTON) {
 		return _("Desktop");
 	} else {
 		return button_data->dir_name;
@@ -1336,6 +1331,7 @@ make_directory_button (NautilusPathBar  *path_bar,
 
         button_data->type = find_button_type (path_bar, path, button_data);
         button_data->button = gtk_toggle_button_new ();
+	gtk_button_set_focus_on_click (GTK_BUTTON (button_data->button), FALSE);
 	
         switch (button_data->type) {
                 case ROOT_BUTTON:
